@@ -421,8 +421,10 @@ class NewGreedyReducedBasis(rp.greedy._ReducedBasis, rp.greedy._IteratedModified
                 ts[next_index], self.basis[:ext_idx])
             self.alphas[ext_idx] = self.alpha_arr(self.basis[ext_idx], ts)
 
-    def make(self, ts, tol, seed_index, num=None):
+    def make(self, ts, tol, seed_index, num=None, rel=False, verbose=True):
         """make initial basis
+
+        rel: default is False. If true then will use relative greedy errors
         """
 
         # Npoints: length of training set
@@ -456,13 +458,21 @@ class NewGreedyReducedBasis(rp.greedy._ReducedBasis, rp.greedy._IteratedModified
         # only true for L2 norm. But not sure why...
         self.errors[0] = np.max(ts_norms)**2
 
+        if rel:
+            tol *= self.errors[0]
+
         # loop over all elements in the training set except for the seed_index
-        print("\nStep \t Error", flush=True)
+        if verbose:
+            print("\nStep \t Error", flush=True)
         step = 0
         flag = 0
         while step < Nbasis:
-            print(f"{step + 1} \t {self.errors[step]}", flush=True)
-
+            if verbose:
+                if rel:
+                    print(
+                        f"{step + 1} \t {self.errors[step]/self.errors[0]}", flush=True)
+                else:
+                    print(f"{step + 1} \t {self.errors[step]}", flush=True)
             # check if tolerance is met
             if self.errors[step] <= tol:
                 if step == 0:
@@ -505,7 +515,7 @@ class NewGreedyReducedBasis(rp.greedy._ReducedBasis, rp.greedy._IteratedModified
             [self.proj_error_from_basis(self.basis, tt) for tt in ts])
         return validation_errors
 
-    def enrich(self, ts, tol, num=None):
+    def enrich(self, ts, tol, num=None, rel=False, verbose=True):
         """enrich basis (add training set (ts) to basis.)
         """
         # Npoints: length of training set
@@ -552,9 +562,9 @@ class NewGreedyReducedBasis(rp.greedy._ReducedBasis, rp.greedy._IteratedModified
 #         self.errors[0] = np.max(self.loss(self.alphas[:idx+1], norms=ts_norms))
 
         # loop over max number of possible number of basis vectors to add.
-        print("\nStep \t Error", flush=True)
+        if verbose:
+            print("\nStep \t Error", flush=True)
         for step in range(-1, Nbasis-1):
-
             # index for extended arrays
             ext_idx = idx + step
 #             print(f"pre iter ext_idx: {ext_idx}")
@@ -562,10 +572,22 @@ class NewGreedyReducedBasis(rp.greedy._ReducedBasis, rp.greedy._IteratedModified
             flag = self.iteration(step, errs, ts, ext_idx=ext_idx)
             if flag == 1:
                 break
+
+            # if first step
+            # this is quite the messy bit of code...
+            if step == -1:
+                if rel:
+                    tol *= self.errors[0]
+
             if self.errors[step+1] <= tol:
                 print("tolerance met. exiting", flush=True)
                 break
-            print(f"{step + 1} \t {self.errors[step+1]}", flush=True)
+            if verbose:
+                if rel:
+                    print(
+                        f"{step + 1} \t {self.errors[step+1]/self.errors[0]}", flush=True)
+                else:
+                    print(f"{step + 1} \t {self.errors[step+1]}", flush=True)
 
         self.size = ext_idx+2
         self.indices = self.indices[:step+2]
